@@ -411,11 +411,11 @@ class TestPlanApiWrapper(NonCodeIndexerToolkit):
     def _index_tool_params(self):
         """Return the parameters for indexing data."""
         return {
+            'chunking_tool': (Literal['html', ''], Field(description="Name of chunking tool", default='html')),
             "plan_id": (int, Field(description="ID of the test plan for which test cases are requested")),
             "suite_ids": (Optional[List[int]], Field(description='List of test suite IDs for which test cases are requested '
                                                                  '(can be empty for all suites indexing from the plan). '
                                                                  'Example: [2, 23]', default=[])),
-            'chunking_tool':(Literal['html', ''], Field(description="Name of chunking tool", default='html'))
         }
 
     @extend_with_parent_available_tools
